==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/CzynnoscRealizacja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class CzynnoscRealizacja extends GenericDPSObject {
    /**
     * CZYNNOSC_REALIZACJA.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long czynnoscId;

    /**
     * CZYNNOSC_REALIZACJA.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long planWsparciaRealizacjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return CZYNNOSC_REALIZACJA.CZYNNOSC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

    /**
     * CZYNNOSC_REALIZACJA.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @return CZYNNOSC_REALIZACJA.PLAN_WSPARCIA_REALIZACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPlanWsparciaRealizacjaId() {
        return planWsparciaRealizacjaId;
    }

    /**
     * CZYNNOSC_REALIZACJA.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @param planWsparciaRealizacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPlanWsparciaRealizacjaId(Long planWsparciaRealizacjaId) {
        this.planWsparciaRealizacjaId = planWsparciaRealizacjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        CzynnoscRealizacja other = (CzynnoscRealizacja) that;
        return (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()))
            && (this.getPlanWsparciaRealizacjaId() == null ? other.getPlanWsparciaRealizacjaId() == null : this.getPlanWsparciaRealizacjaId().equals(other.getPlanWsparciaRealizacjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        result = prime * result + ((getPlanWsparciaRealizacjaId() == null) ? 0 : getPlanWsparciaRealizacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append(", planWsparciaRealizacjaId=").append(planWsparciaRealizacjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/CzynnoscRealizacja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class CzynnoscRealizacja extends GenericDPSObject {
    /**
     * CZYNNOSC_REALIZACJA.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long czynnoscId;

    /**
     * CZYNNOSC_REALIZACJA.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long planWsparciaRealizacjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return CZYNNOSC_REALIZACJA.CZYNNOSC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

    /**
     * CZYNNOSC_REALIZACJA.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @return CZYNNOSC_REALIZACJA.PLAN_WSPARCIA_REALIZACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPlanWsparciaRealizacjaId() {
        return planWsparciaRealizacjaId;
    }

    /**
     * CZYNNOSC_REALIZACJA.PLAN_WSPARCIA_REALIZACJA_ID
     *
     * @param planWsparciaRealizacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPlanWsparciaRealizacjaId(Long planWsparciaRealizacjaId) {
        this.planWsparciaRealizacjaId = planWsparciaRealizacjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        CzynnoscRealizacja other = (CzynnoscRealizacja) that;
        return (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()))
            && (this.getPlanWsparciaRealizacjaId() == null ? other.getPlanWsparciaRealizacjaId() == null : this.getPlanWsparciaRealizacjaId().equals(other.getPlanWsparciaRealizacjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        result = prime * result + ((getPlanWsparciaRealizacjaId() == null) ? 0 : getPlanWsparciaRealizacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append(", planWsparciaRealizacjaId=").append(planWsparciaRealizacjaId);
        sb.append("]");
        return sb.toString();
    }
}
